/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.financialSupervision.modular.fsSaleRevenue.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.financialSupervision.modular.fsSaleRevenue.entity.FsSaleRevenue;
import com.unis.financialSupervision.modular.fsSaleRevenue.mapper.FsSaleRevenueMapper;
import com.unis.financialSupervision.modular.fsSaleRevenue.param.FsSaleRevenueAddParam;
import com.unis.financialSupervision.modular.fsSaleRevenue.param.FsSaleRevenueEditParam;
import com.unis.financialSupervision.modular.fsSaleRevenue.param.FsSaleRevenueIdParam;
import com.unis.financialSupervision.modular.fsSaleRevenue.param.FsSaleRevenuePageParam;
import com.unis.financialSupervision.modular.fsSaleRevenue.service.FsSaleRevenueService;

import java.util.List;

/**
 * 销售收入上缴Service接口实现类
 *
 * @author QSHan
 * @date  2024/07/26 16:30
 **/
@Service
public class FsSaleRevenueServiceImpl extends ServiceImpl<FsSaleRevenueMapper, FsSaleRevenue> implements FsSaleRevenueService {

    @Override
    public Page<FsSaleRevenue> page(FsSaleRevenuePageParam fsSaleRevenuePageParam) {
        QueryWrapper<FsSaleRevenue> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isAllNotEmpty(fsSaleRevenuePageParam.getSortField(), fsSaleRevenuePageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(fsSaleRevenuePageParam.getSortOrder());
            queryWrapper.orderBy(true, fsSaleRevenuePageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(fsSaleRevenuePageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(FsSaleRevenue::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(FsSaleRevenueAddParam fsSaleRevenueAddParam) {
        FsSaleRevenue fsSaleRevenue = BeanUtil.toBean(fsSaleRevenueAddParam, FsSaleRevenue.class);
        this.save(fsSaleRevenue);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(FsSaleRevenueEditParam fsSaleRevenueEditParam) {
        BeanUtil.copyProperties(fsSaleRevenueEditParam, fsSaleRevenue);
        this.updateById(fsSaleRevenue);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<FsSaleRevenueIdParam> fsSaleRevenueIdParamList) {
        // 执行删除
    }

    @Override
    public FsSaleRevenue detail(FsSaleRevenueIdParam fsSaleRevenueIdParam) {
    }

    @Override
    public FsSaleRevenue queryEntity(String id) {
        FsSaleRevenue fsSaleRevenue = this.getById(id);
        if(ObjectUtil.isEmpty(fsSaleRevenue)) {
            throw new CommonException("销售收入上缴不存在，id值为：{}", id);
        }
        return fsSaleRevenue;
    }
}
